// Copyright (c) Mito
import React from 'react';
import '../../css/column-header.css';
import { getHeaderWords } from '../utils/gridStyling';
import { FilterEmptyIcon, FilterNonEmptyIcon } from './icons/FilterIcons';
import { ColumnMitoType } from './Mito';
import { ControlPanelTab } from './taskpanes/ControlPanel/ControlPanelTaskpane';
import { TaskpaneType } from './taskpanes/taskpanes';
// import type icons
import DateTypeIcon from '../components/icons/columntypes/DatetimeTypeIcon';
import StringTypeIcon from '../components/icons/columntypes/StringTypeIcon';
import TimedeltaTypeIcon from '../components/icons/columntypes/TimedeltaTypeIcon';
import NumberTypeIcon from '../components/icons/columntypes/NumberTypeIcon';
import BooleanTypeIcon from '../components/icons/columntypes/BooleanTypeIcon';
export const getTypeIcon = (mitoType) => {
    if (mitoType === ColumnMitoType.STRING_SERIES) {
        return React.createElement(StringTypeIcon, null);
    }
    else if (mitoType === ColumnMitoType.NUMBER_SERIES) {
        return React.createElement(NumberTypeIcon, null);
    }
    else if (mitoType === ColumnMitoType.DATETIME_SERIES) {
        return React.createElement(DateTypeIcon, null);
    }
    else if (mitoType === ColumnMitoType.TIMEDELTA_SERIES) {
        return React.createElement(TimedeltaTypeIcon, null);
    }
    else if (mitoType === ColumnMitoType.BOOLEAN_SERIES) {
        return React.createElement(BooleanTypeIcon, null);
    }
    else {
        // If we can't identify the column, mark it as an object
        return React.createElement(StringTypeIcon, null);
    }
};
/*
  A custom component that AG-Grid displays for the column
  header, that we extend to open the column header popup when clicked.

  NOTE: When you add a prop to this component, you must also pass it as a header
  prop, wherever the column is constructed.
*/
const ColumnHeader = (props) => {
    /*
      we split each word of the header (separated by _) into its own span element, adding the _ to
      the latter half of the split. ie: first_name -> [first, _name]
      This lets us wrap the column headers without breaking words in half, which we would
      do if we just used a fix length cutoff for each row as the cutoff.

      Note: this behaves better when the header's words are <10 characters, but worse when
      the header's words are > 10 characters. The 10 number is decided by the default column width
    */
    const wordsSpans = getHeaderWords(props.columnHeader).map(word => {
        // give the span a random key. we don't use the word because there may be duplicates
        return (React.createElement("span", { key: Math.random() }, word));
    });
    const openControlPanelToFilter = () => {
        props.setSelectedColumn(props.columnHeader);
        props.setCurrOpenTaskpane({
            type: TaskpaneType.CONTROL_PANEL,
            openEditingColumnHeader: false,
        });
        props.setSelectedColumnControlPanelTab(ControlPanelTab.FilterSort);
    };
    return (React.createElement("div", { className: 'column-header-cell', onClick: () => {
            props.setSelectedColumn(props.columnHeader);
        } },
        React.createElement("div", { className: 'column-header-header-container' },
            React.createElement("div", { onClick: () => {
                    props.setSelectedColumn(props.columnHeader);
                    props.setCurrOpenTaskpane({
                        type: TaskpaneType.CONTROL_PANEL,
                        openEditingColumnHeader: true
                    });
                }, className: "column-header-column-header mr-1" }, wordsSpans)),
        React.createElement("div", { className: 'column-header-icon-container' },
            React.createElement("div", { 
                // NOTE: leave this ID here so that tests can find
                // this div element!
                id: 'filter-icon', onClick: openControlPanelToFilter },
                props.filters.length === 0 &&
                    React.createElement(FilterEmptyIcon, null),
                props.filters.length !== 0 &&
                    React.createElement(FilterNonEmptyIcon, null)),
            React.createElement("div", { onClick: openControlPanelToFilter }, getTypeIcon(props.columnMitoType)))));
};
export default ColumnHeader;
//# sourceMappingURL=ColumnHeader.js.map