// Copyright (c) Mito
import React, { useState } from 'react';
import fscreen from 'fscreen';
// Import CSS
import "../../css/mito-toolbar.css";
import { ModalEnum } from './Mito';
// Import Components 
import { TaskpaneType } from './taskpanes/taskpanes';
// Icons!
import UndoIcon from './icons/UndoIcon';
import ImportIcon from './icons/ImportIcon';
import ExportIcon from './icons/ExportIcon';
import ReplayIcon from './icons/ReplayIcon';
import SaveIcon from './icons/SaveIcon';
import MergeIcon from './icons/MergeIcon';
import PivotIcon from './icons/PivotIcon';
import DeleteColumnIcon from './icons/DeleteColumnIcon';
import AddColumnIcon from './icons/AddColumnIcon';
import DocumentationIcon from './icons/DocumentationIcon';
import { CloseFullscreenIcon, OpenFullscreenIcon } from './icons/FullscreenIcons';
import StepsIcon from './icons/StepsIcon';
import FastForwardIcon from './icons/FastForwardIcon';
import GraphIcon from './icons/GraphIcon';
const MitoToolbar = (props) => {
    /* Adds a new column onto the end of a sheet, with A, B, C... as the name */
    const addColumn = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        /*
        * Helper function that, given a number, returns Excel column that corresponds to this number (1-indexed)
        */
        function toColumnName(num) {
            let ret;
            let a = 1;
            let b = 26;
            for (ret = ''; (num -= a) >= 0; a = b, b *= 26) {
                ret = String.fromCharCode(Math.round((num % b) / a) + 65) + ret;
            }
            return ret;
        }
        let inc = 1;
        let newColumnHeader = toColumnName(props.sheetJSON.columns.length + inc);
        // If the column header is in the sheet already, we bump and keep trying
        while (props.sheetJSON.columns.includes(newColumnHeader)) {
            inc++;
            newColumnHeader = toColumnName(props.sheetJSON.columns.length + inc);
        }
        // The new column should be placed 1 position to the right of the selected column
        const newColumnHeaderIndex = props.sheetJSON.columns.findIndex((columnHeader) => columnHeader === props.selectedColumn) + 1;
        void props.mitoAPI.sendColumnAddMessage(props.selectedSheetIndex, newColumnHeader, newColumnHeaderIndex);
    };
    /* Undoes the last step that was created */
    const undo = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        void props.mitoAPI.sendUndoMessage();
    };
    /* Saves the current file as as an exported analysis */
    const downloadAnalysis = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        props.setModal({ type: ModalEnum.Download });
    };
    const [fullscreen, setFullscreen] = useState(false);
    fscreen.onfullscreenchange = () => {
        setFullscreen(!!fscreen.fullscreenElement);
        void props.mitoAPI.sendLogMessage('button_toggle_fullscreen', {
            // Note that this is true when _end_ in fullscreen mode, and 
            // false when we _end_ not in fullscreen mode, which is much
            // more natural than the alternative
            fullscreen: !!fscreen.fullscreenElement
        });
    };
    /*
        Toggles if Mito is full screen or not
    */
    const toggleFullscreen = () => {
        // We toggle to the opposite of whatever the fullscreen actually is (as detected by the
        // fscreen library), and then we set the fullscreen state variable to that state (in the callback
        // above), so that the component rerenders propery
        const isNotFullscreen = fscreen.fullscreenElement === undefined || fscreen.fullscreenElement === null;
        if (isNotFullscreen && props.mitoContainerRef) {
            fscreen.requestFullscreen(props.mitoContainerRef);
        }
        else {
            fscreen.exitFullscreen();
        }
    };
    const openDocumentation = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // We log the opening of the documentation taskpane
        void props.mitoAPI.sendLogMessage('button_documentation_log_event', {
            stage: 'opened'
        });
        // we open the documentation taskpane
        props.setCurrOpenTaskpane({ type: TaskpaneType.DOCUMENTATION });
    };
    const openMerge = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // We open the merge taskpane
        props.setCurrOpenTaskpane({ type: TaskpaneType.MERGE });
    };
    const openPivotTable = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        props.setCurrOpenTaskpane({ type: TaskpaneType.PIVOT });
    };
    const deleteColumn = async () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        // And then delete the column that is up
        await props.mitoAPI.sendDeleteColumn(props.selectedSheetIndex, props.selectedColumn);
    };
    const openSave = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        props.setModal({ type: ModalEnum.SaveAnalysis });
    };
    const openReplay = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        props.setCurrOpenTaskpane({ type: TaskpaneType.REPLAY_ANALYSIS });
    };
    const openImport = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        // we close the editing taskpane if its open
        props.closeOpenEditingPopups();
        props.setCurrOpenTaskpane({ type: TaskpaneType.IMPORT });
    };
    const openGraph = () => {
        // We turn off editing mode, if it is on
        props.setEditingMode(false, "", -1);
        props.setCurrOpenTaskpane({ type: TaskpaneType.GRAPH, graphSidebarSheet: props.selectedSheetIndex });
    };
    const openSteps = () => {
        void props.mitoAPI.sendLogMessage('click_open_steps');
        props.setCurrOpenTaskpane({ type: TaskpaneType.STEPS });
    };
    const fastForward = () => {
        // Fast forwards to the most recent step, allowing editing
        void props.mitoAPI.sendLogMessage('click_fast_forward');
        void props.mitoAPI.checkoutStepByIndex(props.numSteps - 1);
    };
    // Class used to highlight the pivot table toolbar item used by Tour.tsx
    const highlightPivotTableButtonClass = props.highlightPivotTableButton ? 'mito-toolbar-item-draw-attention' : '';
    const highlightAddColButtonClass = props.highlightAddColButton ? 'mito-toolbar-item-draw-attention' : '';
    return (React.createElement("div", { className: 'mito-toolbar-container' },
        React.createElement("div", { className: 'mito-toolbar-container-left' },
            React.createElement("button", { className: 'mito-toolbar-item vertical-align-content', onClick: undo },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(UndoIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Undo")),
            React.createElement("div", { className: "vertical-line mt-1" }),
            React.createElement("button", { className: 'mito-toolbar-item vertical-align-content', id: 'tour-import-button-id', onClick: openImport },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(ImportIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Import")),
            React.createElement("button", { className: 'mito-toolbar-item vertical-align-content', onClick: downloadAnalysis },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(ExportIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Export")),
            React.createElement("div", { className: "vertical-line mt-1" }),
            React.createElement("button", { className: 'mito-toolbar-item vertical-align-content ' + highlightAddColButtonClass, onClick: addColumn },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(AddColumnIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Add Col")),
            React.createElement("button", { className: 'mito-toolbar-item vertical-align-content', onClick: deleteColumn },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(DeleteColumnIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Del Col")),
            React.createElement("div", { className: "vertical-line mt-1" }),
            React.createElement("button", { className: 'mito-toolbar-item ' + highlightPivotTableButtonClass, onClick: openPivotTable },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(PivotIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Pivot")),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openMerge },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(MergeIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Merge")),
            React.createElement("div", { className: "vertical-line mt-1" }),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openGraph },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(GraphIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Graph")),
            React.createElement("div", { className: "vertical-line mt-1" }),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openSave },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(SaveIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Save")),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openReplay },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(ReplayIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Replay"))),
        React.createElement("div", { className: 'mito-toolbar-container-right mr-1' },
            props.currStepIdx !== props.numSteps - 1 &&
                React.createElement("button", { className: 'mito-toolbar-item', onClick: fastForward },
                    React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                        React.createElement(FastForwardIcon, null)),
                    React.createElement("p", { className: 'mito-toolbar-item-label' }, "Fast Forward")),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openSteps },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(StepsIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Steps")),
            React.createElement("button", { className: 'mito-toolbar-item', onClick: openDocumentation },
                React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                    React.createElement(DocumentationIcon, null)),
                React.createElement("p", { className: 'mito-toolbar-item-label' }, "Docs")),
            fullscreen &&
                /*
                    We put the button inside the conditional render to maintain the structure of
                    of the html so fix spacing issues on chrome.
                */
                React.createElement("button", { className: 'mito-toolbar-item', onClick: toggleFullscreen },
                    React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                        React.createElement(CloseFullscreenIcon, null)),
                    React.createElement("p", { className: 'mito-toolbar-item-label' }, "Fullscreen")),
            !fullscreen &&
                React.createElement("button", { className: 'mito-toolbar-item', onClick: toggleFullscreen },
                    React.createElement("div", { className: 'mito-toolbar-item-icon-container' },
                        React.createElement(OpenFullscreenIcon, null)),
                    React.createElement("p", { className: 'mito-toolbar-item-label' }, "Fullscreen")))));
};
export default MitoToolbar;
//# sourceMappingURL=MitoToolbar.js.map