// Copyright (c) Mito
import React from 'react';
// import css
import "../../../../css/column-header-modal.css";
import "../../../../css/column-name-card.css";
import TaskpaneError from '../TaskpaneError';
import { TaskpaneType } from '../taskpanes';
import { isValidHeader, getHeaderErrorMessage } from './renameUtils';
/*
    A modal that allows a user to sort a column
*/
class ColumnNameCard extends React.Component {
    constructor(props) {
        super(props);
        this.updateUnsubmittedNewColumnHeader = (e) => {
            const newColumnHeader = e.target.value;
            // Update the saved unsubmittedColumnHeader
            this.setState({
                unsubmittedNewColumnHeader: newColumnHeader
            });
            // Display an error message, if it has one
            this.setInvalidInputError(getHeaderErrorMessage(newColumnHeader));
        };
        this.changeColumnHeader = async () => {
            if (!isValidHeader(this.state.unsubmittedNewColumnHeader)) {
                // We make sure the new column header is a valid mito column,
                // and we don't allow the user to submit if it's not! 
                // We also update the error to tell them to fix the issue.
                this.setInvalidInputError(`Please fix issues before submitting: ${getHeaderErrorMessage(this.state.unsubmittedNewColumnHeader)}`);
                return;
            }
            // If the column header did not change, just stop renaming without updating the name to avoid error
            if (this.state.columnHeader == this.state.unsubmittedNewColumnHeader) {
                this.setState({
                    isRename: false
                });
                return;
            }
            const stepID = await this.props.mitoAPI.sendRenameColumn(this.props.selectedSheetIndex, this.state.columnHeader, this.state.unsubmittedNewColumnHeader, this.state.stepID);
            this.setState(prevState => {
                return {
                    stepID: stepID,
                    isRename: false,
                    columnHeader: prevState.unsubmittedNewColumnHeader,
                    unsubmittedNewColumnHeader: prevState.unsubmittedNewColumnHeader
                };
            });
            this.props.setCurrOpenTaskpane({ type: TaskpaneType.CONTROL_PANEL, openEditingColumnHeader: false });
        };
        this.state = {
            columnHeader: props.columnHeader,
            unsubmittedNewColumnHeader: props.columnHeader,
            invalidInputError: '',
            isRename: props.openEditingColumnHeader,
            stepID: ''
        };
        this.setColumnHeader = this.setColumnHeader.bind(this);
        this.updateUnsubmittedNewColumnHeader = this.updateUnsubmittedNewColumnHeader.bind(this);
        this.setInvalidInputError = this.setInvalidInputError.bind(this);
        this.setIsRename = this.setIsRename.bind(this);
    }
    setColumnHeader(columnHeader) {
        this.setState({
            columnHeader: columnHeader
        });
    }
    setInvalidInputError(errorMessage) {
        this.setState({
            invalidInputError: errorMessage
        });
    }
    setIsRename(isRename) {
        this.setState(prevState => {
            return {
                isRename: isRename,
                unsubmittedNewColumnHeader: prevState.columnHeader
            };
        });
    }
    render() {
        return (React.createElement("div", { className: 'column-name-card-container' },
            React.createElement("div", { className: 'default-taskpane-header-div' },
                React.createElement("div", { className: 'column-name-card-column-name-div', onClick: () => {
                        if (!this.state.isRename) {
                            this.setIsRename(!this.state.isRename);
                            this.setInvalidInputError('');
                        }
                    } },
                    this.state.isRename &&
                        React.createElement("form", { onSubmit: (e) => { e.preventDefault(); void this.changeColumnHeader(); }, onBlur: (e) => { e.preventDefault(); void this.changeColumnHeader(); } },
                            React.createElement("input", { type: 'text', className: 'column-name-card-input-text', value: this.state.unsubmittedNewColumnHeader, onChange: (e) => { this.updateUnsubmittedNewColumnHeader(e); }, autoFocus: true })),
                    !this.state.isRename &&
                        React.createElement("p", { className: 'column-name-card-column-header' }, this.state.columnHeader)),
                React.createElement("div", { className: 'default-taskpane-header-exit-button-div', onClick: () => this.props.setCurrOpenTaskpane({ type: TaskpaneType.NONE }) },
                    React.createElement("svg", { width: "18", height: "18", viewBox: "0 0 13 13", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
                        React.createElement("line", { x1: "0.707107", y1: "1.29289", x2: "11.3136", y2: "11.8994", stroke: "#343434", strokeWidth: "2" }),
                        React.createElement("line", { x1: "0.7072", y1: "11.8995", x2: "11.3137", y2: "1.29297", stroke: "#343434", strokeWidth: "2" })))),
            React.createElement(TaskpaneError, { message: this.state.invalidInputError })));
    }
}
export default ColumnNameCard;
//# sourceMappingURL=ColumnNameCard.js.map