// Copyright (c) Mito
import React from 'react';
import '../../../../css/documentation-taskpane.css';
const listIcon = (React.createElement("svg", { width: "16", height: "18", viewBox: "0 0 16 18", fill: "none", xmlns: "http://www.w3.org/2000/svg" },
    React.createElement("mask", { id: "path-1-inside-1", fill: "white" },
        React.createElement("rect", { width: "16", height: "18", rx: "1" })),
    React.createElement("rect", { width: "16", height: "18", rx: "1", stroke: "#0081DE", strokeWidth: "2.4", mask: "url(#path-1-inside-1)" }),
    React.createElement("line", { x1: "2", y1: "3.2", x2: "14", y2: "3.2", stroke: "#0081DE", strokeWidth: "1.2" }),
    React.createElement("line", { x1: "2", y1: "7", x2: "14", y2: "7", stroke: "#0081DE", strokeWidth: "1.2" }),
    React.createElement("line", { x1: "2", y1: "10.8", x2: "14", y2: "10.8", stroke: "#0081DE", strokeWidth: "1.2" }),
    React.createElement("line", { x1: "2", y1: "14.6", x2: "14", y2: "14.6", stroke: "#0081DE", strokeWidth: "1.2" })));
import { functionDocumentationObjects } from '../../../data/function_documentation';
import { basicExamples } from './BasicExampleContainer';
import { TaskpaneType } from '../taskpanes';
import { FeedbackOpenLocation } from '../Feedback/FeedbackTaskpane';
/*
    This documentation taskpane content displays a list of all
    documentation entries users can select.

    These are either:
    1. Basic examples (e.g. how to write a formula)
    2. Function documentations
*/
const DocumentationListContent = (props) => {
    const basicExamplesList = basicExamples.map((basicExample) => {
        return (React.createElement("li", { className: 'documentation-taskpane-content-function-list-element', key: basicExample.basicExampleName, onClick: () => {
                // Log the selection of the basic documentation
                // NOTE: we don't need to wait on this promise, as we don't care when
                // it finishes
                void props.mitoAPI.sendLogMessage('documentation_log_event', {
                    kind: 'basic',
                    function: basicExample.basicExampleName
                });
                // Set the documentation element
                props.setSelectedDocumentation({
                    kind: 'basic',
                    basicExampleName: basicExample.basicExampleName
                });
            } },
            React.createElement("div", { className: 'documentation-taskpane-content-function-list-icon' }, listIcon),
            basicExample.basicExampleName));
    });
    const functionNameList = functionDocumentationObjects.map((funcDocObject) => {
        return (React.createElement("li", { className: 'documentation-taskpane-content-function-list-element', key: funcDocObject.function, onClick: () => {
                // Log they selected this function
                // NOTE: we don't need to wait on this promise, as we don't care
                // when it finishes
                void props.mitoAPI.sendLogMessage('documentation_log_event', {
                    kind: 'function',
                    function: funcDocObject.function
                });
                // Set the documentation
                props.setSelectedDocumentation({
                    kind: 'function',
                    function: funcDocObject.function
                });
            } },
            React.createElement("div", { className: 'documentation-taskpane-content-function-list-icon' }, listIcon),
            funcDocObject.function));
    });
    return (React.createElement(React.Fragment, null,
        React.createElement("button", { className: 'blue-button txt-16', onClick: () => { props.setCurrOpenTaskpane({ type: TaskpaneType.FEEDBACK, openLocation: FeedbackOpenLocation.FROM_DOCUMENTATION }); } }, "Provide Feedback"),
        React.createElement("div", { className: 'documentation-taskpane-content-function-list-title mt-10px' }, "Basic Examples"),
        React.createElement("ul", { className: 'documentation-taskpane-content-function-list' }, basicExamplesList),
        React.createElement("div", { className: 'documentation-taskpane-content-function-list-section-title' }, "Functions"),
        React.createElement("ul", { className: 'documentation-taskpane-content-function-list' }, functionNameList)));
};
export default DocumentationListContent;
//# sourceMappingURL=DocumentationListContent.js.map